@@ -2,9 +2,6 @@ from django.contrib import auth
 from django.core.exceptions import ValidationError
 from django.db import transaction
 from django.template.defaultfilters import slugify
-from firebase_token_generator import create_token
-from django.conf import settings
-
 
 from rest_framework import serializers
 from rest_framework import relations
@@ -147,18 +144,6 @@ class UserSerializer(serializers.ModelSerializer):
             "short_name": obj.get_short_name()
         }
 
-        # ensure this variable exists
-        secret = getattr(settings, 'FIREBASE_SECRET', None)
-        if secret:
-            # use firebase auth to provide auth variables to firebase security api
-            firebase_auth_payload = {
-                'id': obj.pk,
-                'username': obj.username,
-                'email': obj.email,
-                'is_staff': obj.is_staff
-            }
-            json['firebase_token'] = create_token(secret, firebase_auth_payload)
-
         return json
 
 
